# Torii-HDL Board Definitions

This package contains evaluation board definitions for [Torii](https://github.com/shrine-maiden-heavy-industries/torii-hdl)

## License

Torii and it's board definitions are released under the [BSD-2-Clause](https://spdx.org/licenses/BSD-2-Clause.html), the full text of which can be found in the [LICENSE](LICENSE) file.
